@@ -39,6 +39,16 @@ class Hello(metaclass=jsii.JSIIMeta, jsii_type="mca-projen-jsii-example.Hello"):
     def __init__(self) -> None:
         jsii.create(self.__class__, self, [])
 
+    @jsii.member(jsii_name="sayGodbye")
+    def say_godbye(self, name: builtins.str) -> builtins.str:
+        '''My sayGodbye function.
+
+        :param name: Someone who calls.
+
+        :return: Godbye
+        '''
+        return typing.cast(builtins.str, jsii.invoke(self, "sayGodbye", [name]))
+
     @jsii.member(jsii_name="sayHello")
     def say_hello(self, name: builtins.str) -> builtins.str:
         '''My sayHello function.
